@@ -311,7 +311,7 @@ class Checker:
             and  SUBSTR(p.relname, 1, 3) != 'vw_'
             -- We cannot check for vw_ views,
             -- because they are created after that script
-        ORDER BY p.relname, /*t.tgname, */pp.prosrc"""
+        ORDER BY p.relname, t.tgname, pp.prosrc"""
 
         return self.__check_equals(query)
 
